@@ -1,15 +1,13 @@
 ﻿#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import os
-from PyQt4 import QtWebKit, QtCore
+import os, re
+from PyQt4 import QtCore, QtGui
 from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply
 
 class QonsoExtractor:
    def __init__(self):
       self.debug = os.environ.has_key('DEBUG')
-      self.page = QtWebKit.QWebPage()
-      self.frame = self.page.currentFrame()
       self.urlconso = ""
       self.urlbeforeAuth = ""
       self.urlAuth = ""
@@ -17,6 +15,13 @@ class QonsoExtractor:
       self.login = ""
       self.password = ""
       self.model = None
+      self.view = None
+      self.hmReS = ".*?((?:\s*\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?)).*?"
+      self.hmRe = re.compile(self.hmReS)
+      self.datasExtracted = False
+      self.authentication = ''
+      self.context = ''
+      self.status = ''
       
    def SetView(self, view):
       self.view = view
@@ -35,9 +40,11 @@ class QonsoExtractor:
       # f.close()
       
    def SetStatus(self, status, context):
+      self.Debug(status+" : "+context)
       self.context = context
       self.status = status
-      self.view.update()
+      if self.view:
+         self.view.update()
 
    def GetStatus(self):
       return (self.status, self.context)
@@ -51,6 +58,7 @@ class QonsoExtractor:
    def InitAuthenticate(self):
       if not self.login or not self.password:
          return
+      self.authentication = 'Init'
 
       self.SetStatus('INFO', 'Connection au site...')
       
@@ -63,7 +71,6 @@ class QonsoExtractor:
       request = QNetworkRequest()
       request.setUrl( QtCore.QUrl(self.urlbeforeAuth ) ) 
       self.manager.get(request)
-      self.authentication = 'Init'
 
    def Authenticate(self, idCorrelation):
       pass
