@@ -3,7 +3,7 @@
 
 import re 
 from QonsoExtractor import QonsoExtractor
-from PyQt4 import QtCore
+from PyQt4 import QtWebKit, QtCore
 from PyQt4.QtNetwork import QNetworkRequest
 
 class QonsoExtractorBouygues(QonsoExtractor):
@@ -36,12 +36,14 @@ class QonsoExtractorBouygues(QonsoExtractor):
       
    def DoReadResponse(self, reply):
       request = QNetworkRequest()
+      page = QtWebKit.QWebPage()
+      frame = page.currentFrame()
 
       # Phase d'initialisation, on va extraire 'idCorrelation', et on lance l'authentification avec
       if self.authentication=='Init':
          html = reply.readAll()
-         self.frame.setHtml(str(html))
-         idCorrelation = self.frame.findFirstElement('input[name=idCorrelation]').attribute('value')
+         frame.setHtml(str(html))
+         idCorrelation = frame.findFirstElement('input[name=idCorrelation]').attribute('value')
          self.authentication = 'InProgress'
          self.Authenticate(idCorrelation)
       
@@ -68,8 +70,8 @@ class QonsoExtractorBouygues(QonsoExtractor):
             self.Debug("No more redirection")
             # pas de redirection, on vérifie s'il n'y a pas d'erreur dans la page
             html = reply.readAll()
-            self.frame.setHtml(str(html))
-            errors = self.frame.findAllElements('div[class=erreur]')
+            frame.setHtml(str(html))
+            errors = frame.findAllElements('div[class=erreur]')
             if errors:
                self.Debug("found erreur")
                for error in errors:
@@ -88,43 +90,97 @@ class QonsoExtractorBouygues(QonsoExtractor):
                self.SetStatus('INFO', 'R&eacute;cup&eacute;ration des donn&eacute;es...')
             
          self.manager.get(request)
-
-
+         
    def ExtractDatas(self, datas):
       self.Debug("ExtractDatas")
       self.SetStatus('INFO', 'R&eacute;cup&eacute;ration des donn&eacute;es...')
 
-      self.frame.setHtml( str(datas) )
+      strElem = str(datas)
       
-      date = self.frame.findFirstElement('span[id="viewConsoFacture:okMetier:encartVoix:DetailConsoDateConso"]').toPlainText()
-      time = self.frame.findFirstElement('span[id="viewConsoFacture:okMetier:encartVoix:DetailConsoHeureConso"]').toPlainText()
-      self.model.lastTime = "Ma consommation au "+date + " &agrave; " + time
+      # Date de la dernière communication
+      date = ""
+      res = re.search('DetailConsoDateConso">(\d{1,2}/\d{1,2}/\d{2,4})<', strElem)
+      if res:
+         date = res.group(1)
 
-      elem = self.frame.findAllElements('div td strong span')
-      
-      self.model.SetConsoVoix( str(elem.at(0).toPlainText().toAscii()) )
-#      self.model.data = elem.at(1).toPlainText()
-      self.model.hforfait = elem.at(1).toPlainText()
+      # Heure de la dernière communication
+      time = ""
+      res = re.search('DetailConsoHeureConso">(\d{1,2}h\d{1,2})<', strElem)
+      if res:
+         time = res.group(1)
 
-      date = self.frame.findFirstElement('span[id="viewConsoFacture:okMetier:encartDateFacture:dateEmissionFacture"]').toPlainText()
-      self.model.facture = "Prochaine facture : "+date+" au soir"
-      self.model.sms = "0"
+      if date and time:
+         self.model.lastTime = "Ma consommation au "+date + " &agrave; " + time
 
-      elem = self.frame.findAllElements('div[class="intitule"]')
-      for i in range (elem.count()):
-         strElem = str( elem.at(i).toPlainText().toUtf8() )
-         self.Debug("____________________________________________\n"+str(i)+" : "+strElem)
+      # Date de la prochaine facture
+      res = re.search('dateEmissionFacture">(\d{1,2}/\d{1,2}/\d{2,4})<', strElem)
+      if res:
+         date = res.group(1)
+         self.model.facture = "Prochaine facture : "+date+" au soir"
+
+      # SMS
+      self.Debug("____________________________________________\nConso SMS")
+      self.Debug("-----------------------------------------------\n")
+      res = re.search("Sur votre forfait de (\d+) SMS.+vous avez consomm.+?(\d+) SMS", strElem, re.IGNORECASE)
+      if res:
+         self.Debug(res.groups())
+         self.model.SetConsoSMS( res.group(2) )
+         self.model.SetConsoSMSMax( res.group(1) )
+
+      # Bonus SMS
+      # res = re.search("Sur votre forfait de (\d+) SMS.+vous avez consomm.+?(\d+) SMS", strElem, re.IGNORECASE)
+      # if res:
+         # self.Debug(res.groups())
+         # self.model.SetConsoSMS( res.group(2) )
+         # self.model.SetConsoSMSMax( res.group(1) )
+         
+      # Conso Voix
+      self.Debug("____________________________________________\nConso voix")
+      self.Debug("-----------------------------------------------\n")
+      res = re.search("Sur votre forfait (.+) de %s.+vous avez consomm.+?%s" %(self.hmReS, self.hmReS), strElem, re.IGNORECASE)
+      if res:
+         self.Debug(res.groups())
+         self.model.SetForfait( res.group(1) )
+         if self.model.forfait.find("Neo")>-1:
+            self.model.dataMax = 500
+         if self.model.forfait.find("Evasio")>-1:
+            self.model.dataMax = 500
+         self.model.SetConsoVoixMax( res.group(2) )
+         self.model.SetConsoVoix( res.group(3) )
+
+      # Conso Voix Supplémentaire
+      if self.model.forfait.find("Evasio")>-1:
+         self.Debug("____________________________________________\nConso voix Supplémentaire")
          self.Debug("-----------------------------------------------\n")
+         res = re.search("Sur votre enveloppe.+vous avez consomm.+%s"%self.hmReS, strElem, re.IGNORECASE)
+         if res:
+            self.Debug(res.groups())
+            self.model.SetConsoVoixSupp( res.group(1) )
 
-         res = re.search("report de minutes de (\d*\s*[Hh]*\s*\d\d)", strElem)
+      # Report de minutes
+      self.Debug("____________________________________________\nReport de minutes")
+      self.Debug("-----------------------------------------------\n")
+      res = re.search("report de minutes.*Pas de report", strElem, re.IGNORECASE)
+      if not res:
+         res = re.search("report de minutes.*?<span>.*?%s.*?</span>"%self.hmReS, strElem, re.IGNORECASE)
          if res:
             self.model.SetReport( res.group(1) )
             self.Debug("report = "+res.group(1))
-         
-         res = re.search("Sur votre forfait (.+).* de (\d*\s*[Hh]*\s*\d\d)", strElem )
-         if res:
-            if res.group(1).find("Neo")>0:
-               self.model.dataMax = 500
-            self.model.SetConsoVoixMax( res.group(2) )
+         else:
+            res = re.search("report de minutes de\s*%s" % self.hmReS, strElem, re.IGNORECASE)
+            if res:
+               self.model.SetReport( res.group(1) )
+               self.Debug("report = "+res.group(1))
 
-      self.view.update()
+      # Hors forfait
+      self.Debug("____________________________________________\nHors forfait")
+      self.Debug("-----------------------------------------------\n")
+      reHForfait = re.compile(u"montant hors forfait.*?(\d+[\.,]?\d*)\s", re.IGNORECASE|re.DOTALL)
+      res = reHForfait.search(strElem)
+      if res:
+         self.model.SetConsoHorsForfait( res.group(1) )
+         self.Debug("hforfait = "+res.group(1))
+      
+      self.datasExtracted = True
+      if self.view:
+         self.view.update()
