@@ -7,21 +7,39 @@ class QonsoModel:
    def __init__(self):
       self.lastTime = ""
       self.voix = dict(int=0, str="0 min")
+      self.voixSupp = dict(int=0, str="0 min")
       self.voixMax = dict(int=0, str="0 min")
       self.data = ""
       self.dataMax = 0
+      self.forfait = ""
       self.hforfait = ""
       self.facture = "Prochaine facture : "
-      self.sms = ""
+      self.sms = '0'
+      self.smsMax = '0'
       self.report = dict(int=0, str="Pas de minutes report&eacute;es ce mois ci")
-      self.regHM = "(\d+)*?\s*[Hh]?\s*(\d\d\d*)"
-
+      self.regHM = "(\d+\s*[Hh])?\s*(\d+)"
+#      self.regHM = "(\d+)*?\s*[Hh]?\s*(\d+)"
+      
    def GetLastTime(self):
       return self.lastTime
 
-   def GetForfait(self):
-      return "Neo.3 illimite de 21h30 a 8h"
+   def SetForfait(self, forfait):
+      self.forfait = forfait
 
+   def GetForfait(self):
+      return self.forfait
+
+   def TimeStrFromInt(self, timenum):
+      h = int(timenum/60)
+      m = timenum-h*60
+
+      timestr = ""
+      if h>=1:
+         timestr = str(h)+"h"
+      timestr = "%s%.2d min"%(timestr, m)
+      return timestr
+   
+      
    def ExtractTime(self, s):
       res = re.search(self.regHM, s)
       timenum = 0
@@ -30,19 +48,19 @@ class QonsoModel:
       if res:
          h = 0
          if res.group(1):
-            h = int(res.group(1))
+            h = int(res.group(1)[:-1])
          m = int(res.group(2))
          timenum = h*60+m
-         h = int(timenum/60)
-         m = timenum-h*60
-
-         timestr = ""
-         if h>=1:
-            timestr = str(h)+"h"
-         timestr = "%s%.2d min"%(timestr, m)
+         timestr = self.TimeStrFromInt(timenum)
       
       return timenum, timestr
       
+   ## 
+   # Certains opérateurs donnent le temps restant au lieu du temps consommé, on recalcule ça
+   def InvertConsoVoix(self):
+      self.voix['int'] = self.voixMax['int']-self.voix['int']
+      self.voix['str'] = self.TimeStrFromInt(self.voix['int'])
+      
    ## 
    # Remplit les données pour la consommation voix
    # @param s  string contenant les données au format [hh]h[mm] (ex : 2h 30)
@@ -56,6 +74,19 @@ class QonsoModel:
    def GetConsoVoix(self, type):
       return self.voix[type]
 
+   ## 
+   # Remplit les données pour la consommation voix
+   # @param s  string contenant les données au format [hh]h[mm] (ex : 2h 30)
+   def SetConsoVoixSupp(self, s):
+      self.voixSupp['int'], self.voixSupp['str'] = self.ExtractTime(s)
+   
+   ##
+   # Renvoit la consommation voix, en fonction du type
+   # @param type  string prenant comme valeur 'int' ou 'str'
+   # @return  consommation voix en minutes (int), ou au format 2h30 (str)
+   def GetConsoVoixSupp(self, type):
+      return self.voixSupp[type]
+
    ## 
    # Remplit la durée du forfait pour la consommation voix
    # @param s  string contenant les données au format [hh]h[mm] (ex : 2h 30)
@@ -84,12 +115,36 @@ class QonsoModel:
    def GetConsoDataMax(self):
       return self.dataMax
 
+   ##
+   # Renvoit le nombre de SMS émis
+   # @param sms  int  Nombre de sms
+   def SetConsoSMS(self, sms):
+      self.sms = sms
+
    ##
    # Renvoit le nombre de SMS émis
    # @return  nombre de SMS
    def GetConsoSMS(self):
       return self.sms
 
+   ##
+   # Renvoit le nombre de SMS disponibles dans le forfait
+   # @param sms  int  Nombre de sms
+   def SetConsoSMSMax(self, sms):
+      self.smsMax = sms
+
+   ##
+   # Renvoit le nombre de SMS dispo dans le forfait
+   # @return  nombre de SMS
+   def GetConsoSMSMax(self):
+      return self.smsMax
+
+   ##
+   # Replit le montant de la consommation hors forfait 
+   # @param hforfait  int
+   def SetConsoHorsForfait(self, hforfait):
+      self.hforfait = str(hforfait)+" &euro;"
+
    ##
    # Renvoit le montant de la consommation hors forfait
    # @return  consommation hors forfait en Euros
