@@ -1,7 +1,7 @@
 ﻿#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import os
+import os, sys
 from PyQt4 import QtGui, QtCore
 import QonsoFactory
 from QonsoModel import QonsoModel
@@ -9,13 +9,12 @@ from DlgConfig import DlgConfig
 from WProgress import WProgress
 
 class QonsoView(QtGui.QMainWindow):
-   def __init__(self, parent=None):
+   def __init__(self, argv, parent=None):
       QtGui.QMainWindow.__init__(self, parent)
       
       self.offline = os.environ.has_key('OFFLINE')
       self.setMaximumSize(QtCore.QSize(800, 480))
       self.setWindowTitle('Qonso')
-      #self.setStyleSheet("background-color: #FFF;" )
       
       try:
          self.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
@@ -32,7 +31,7 @@ class QonsoView(QtGui.QMainWindow):
       if not self.config.GetLogin() or not self.config.GetPassword() or not self.config.GetOperator():
          self.config.AskForCredentials()
       
-      self.CreateExtractor()
+      self.CreateExtractor( self.config.GetOperator() )
       
       self.layoutsOK = False
       self.centralWidget = QtGui.QWidget()
@@ -42,17 +41,17 @@ class QonsoView(QtGui.QMainWindow):
       self.setCentralWidget( self.centralWidget )
 
       self.credentialsOk = True
+      self.CreateAppLayouts()
 
-      if not self.offline:
-         self.extractor.InitAuthenticate()
-      else:
-         f = open(r"..\..\..\data\Bouygues.html", "r")
+      if self.offline:
+         self.CreateConsoLayouts()
+         self.CreateExtractor(sys.argv[1])
+         f = open( sys.argv[2], "r")
          self.extractor.ExtractDatas( f.read() )
          f.close()
 
-
-   def CreateExtractor(self):
-      self.extractor = QonsoFactory.CreateExtractor( self.config.GetOperator() )
+   def CreateExtractor(self, op):
+      self.extractor = QonsoFactory.CreateExtractor(op)
       self.extractor.SetView(self)
       self.extractor.SetLogin(self.config.GetLogin())
       self.extractor.SetPassword(self.config.GetPassword())
@@ -61,13 +60,10 @@ class QonsoView(QtGui.QMainWindow):
    def Settings(self):
       self.config.AskForCredentials()
       self.credentialsOk = True
-      self.CreateExtractor()
+      self.CreateExtractor(self.config.GetOperator())
       self.extractor.InitAuthenticate()
-      return
-      
-   def CreateLayouts(self):
-      self.layoutsOK = True
       
+   def CreateAppLayouts(self):      
       exit = QtGui.QAction(QtGui.QIcon('icons/exit.png'), u'Paramètres', self)
       exit.setShortcut('Ctrl+O')
       exit.setStatusTip('Options')
@@ -76,26 +72,39 @@ class QonsoView(QtGui.QMainWindow):
       menubar = self.menuBar()
       file = menubar.addMenu('&Options')
       file.addAction(exit)
-   
-      compteBox = self.CreateLayout('lasttime', None)
-      voixBox = self.CreateLayout('voix', '/opt/qonso/icons/voix.png', True)
-      smsBox = self.CreateLayout('sms', '/opt/qonso/icons/sms.png')
-      dataBox = self.CreateLayout('data', '/opt/qonso/icons/data.png', True)
-      hforfaitBox = self.CreateLayout('hforfait', '/opt/qonso/icons/hforfait.png', False)
-      factureBox = self.CreateLayout('facture', None)
 
-      self.UpdateConsoText()
+      compteBox = self.CreateLayout('lasttime', None)
+      self.vbox.addLayout(compteBox)
       
       self.vbox.setSpacing(0)
       self.vbox.setMargin(0)
-
-      self.vbox.addLayout(compteBox)
+      self.layoutsOK = True
+   
+   
+   def CreateConsoLayouts(self):
+      iconPath = '/opt/qonso/icons'
+      if not os.path.exists(iconPath):
+         iconPath = 'icons'
+      
+      voixBox = self.CreateLayout('voix', os.path.join(iconPath, 'voix.png'), True)
       self.vbox.addLayout(voixBox)
-      self.vbox.addLayout(smsBox)
+      
+      if self.model.GetConsoSMSMax() != '0':
+         smsBox = self.CreateLayout('sms', os.path.join(iconPath, 'sms.png') )
+         self.vbox.addLayout(smsBox)
+         
+      dataBox = self.CreateLayout('data', os.path.join(iconPath, 'data.png'), True)
       self.vbox.addLayout(dataBox)
+
+      hforfaitBox = self.CreateLayout('hforfait', os.path.join(iconPath, 'hforfait.png'), False)
       self.vbox.addLayout(hforfaitBox)
+
+      factureBox = self.CreateLayout('facture', None)
       self.vbox.addLayout(factureBox)
 
+      self.UpdateConsoText()
+      
+
    def CreateLayout(self, name, icon, progress=False):
       box = QtGui.QHBoxLayout()
       box.setSpacing(0)
@@ -103,7 +112,7 @@ class QonsoView(QtGui.QMainWindow):
          pixicon = QtGui.QPixmap(icon).scaled(64,64)
          label = QtGui.QLabel()
          label.setMinimumSize(QtCore.QSize(74, 74))
-         label.setMaximumSize(QtCore.QSize(96, 134))
+         label.setMaximumSize(QtCore.QSize(96, 200))
          label.setStyleSheet("background: #fff; margin: 0; padding: 5px; border-bottom: 1px solid #269CCA;")
          label.setPixmap(pixicon)
          box.addWidget(label)
@@ -134,11 +143,11 @@ class QonsoView(QtGui.QMainWindow):
       box.addLayout(vbox)
          
       self.labels[name] = data, wid
-      self.layoutsOK = True
       return box
 
    def UpdateConsoText(self):
       status, context = self.extractor.GetStatus()
+      
       if status=='ERROR':
          self.SetText(self.labels['lasttime'][0], "#FF0000", 10, context)
       else:
@@ -148,32 +157,42 @@ class QonsoView(QtGui.QMainWindow):
             self.SetText(self.labels['lasttime'][0], "#269CCA", 16, self.model.GetLastTime()+
                          "<br/>"+self.model.GetReport('str'))
          
-      self.SetText(self.labels['voix'][0], "#EB5F18", 22, self.model.GetConsoVoix('str')+" / "+self.model.GetConsoVoixMax('str') )
-      self.labels['voix'][1].setRange(0, self.model.GetConsoVoixMax('int'))
-      self.labels['voix'][1].setValue( self.model.GetConsoVoix('int') )
+      if self.labels.has_key('voix'):
+         self.SetText(self.labels['voix'][0], "#EB5F18", 22, self.model.GetConsoVoix('str')+" / "+self.model.GetConsoVoixMax('str') )
+         self.labels['voix'][1].setRange(0, self.model.GetConsoVoixMax('int'))
+         self.labels['voix'][1].setValue( self.model.GetConsoVoix('int') )
 
-      self.SetText(self.labels['sms'][0], "#EB5F18", 22, self.model.GetConsoSMS())
+      if self.model.GetConsoSMSMax() != '0':
+         self.SetText(self.labels['sms'][0], "#EB5F18", 22, self.model.GetConsoSMS() +"/" + self.model.GetConsoSMSMax())
 
-      dataMax = self.model.GetConsoDataMax()
-      data = self.model.GetConsoData()
-      self.SetText(self.labels['data'][0], "#EB5F18", 22, str(data)+" / "+str(dataMax)+"Mo")
-      self.labels['data'][1].setRange(0, dataMax)
-      self.labels['data'][1].setValue( data )
+      if self.labels.has_key('data'):
+         dataMax = self.model.GetConsoDataMax()
+         data = self.model.GetConsoData()
+         self.SetText(self.labels['data'][0], "#EB5F18", 22, str(data)+" / "+str(dataMax)+"Mo")
+         self.labels['data'][1].setRange(0, dataMax)
+         self.labels['data'][1].setValue( data )
       
-      self.SetText(self.labels['hforfait'][0], "#EB5F18", 22, self.model.GetConsoHorsForfait() )
-      self.SetText(self.labels['facture'][0], "#269CCA", 16, self.model.GetDateProchaineFacture())
+      if self.labels.has_key('hforfait'):
+         self.SetText(self.labels['hforfait'][0], "#EB5F18", 22, self.model.GetConsoHorsForfait() )
+         
+      if self.labels.has_key('facture'):
+         self.SetText(self.labels['facture'][0], "#269CCA", 16, self.model.GetDateProchaineFacture())
 
    def SetText(self, label, color, size, text):
       label.setText('<span style="color: %s; font-weight: bold; font-size: %dpt">%s</span>' % (color, size, text))
    
    def paintEvent(self, event):
-      if self.credentialsOk and not self.layoutsOK:
+      if self.credentialsOk and not self.extractor.authentication:
          if not self.offline:
             self.extractor.InitAuthenticate()
-         self.CreateLayouts()
       elif self.layoutsOK:
-         self.UpdateConsoText()
+         if self.extractor.datasExtracted:
+            self.CreateConsoLayouts()
+            self.extractor.datasExtracted = False 
+            
+      self.UpdateConsoText()
       
    def closeEvent(self, event):
       self.config.WriteConfig()
       event.accept()
+	  
